using System;
using T = System.Diagnostics.Trace;

namespace Tracing
{

	public class DataAccess
	{
		public void Open()
		{
			try 
			{
				T.WriteLineIf(Globals.Trace, "DataAccess.Open():");
				T.Indent();
				T.WriteLineIf(Globals.Trace, "Connection string=...");
				//
				// ...
				//
				T.WriteLineIf(Globals.Trace, "Opened!");
			}
			catch(Exception ex) 
			{
				T.WriteLineIf(Globals.Trace, ex.GetType() + ": " + ex.Message);
				T.WriteLineIf(Globals.Trace, ex.StackTrace);
			}
			finally 
			{
				T.Unindent();
				T.Flush();
			}
		}

		public void UpdateCreditLimit(string name, decimal creditLimit)
		{
			string  sql;
			int     recordsUpdated;

			try 
			{
				T.WriteLineIf(Globals.Trace, "DataAccess.UpdateCreditLimit(name, creditLimit):");
				T.Indent();
				T.WriteLineIf(Globals.Trace, name);
				T.WriteLineIf(Globals.Trace, creditLimit);

				if (name.Trim().Equals(""))
					throw new ArgumentException("customer name cannot be null.");
				if (creditLimit < 0.0M)
					throw new ArgumentException("new credit limit cannot be negative.");

				sql = "UPDATE Customers SET ...";
				T.WriteLineIf(Globals.Trace, sql);
				//
				// ...
				//
				recordsUpdated = 1;
				T.WriteLineIf(Globals.Trace, recordsUpdated);

				T.WriteLineIf(Globals.Trace, "Updated!");
			}
			catch(Exception ex) 
			{
				T.WriteLineIf(Globals.Trace, ex.GetType() + ": " + ex.Message);
				T.WriteLineIf(Globals.Trace, ex.StackTrace);
				throw ex;
			}
			finally 
			{
				T.Unindent();
				T.Flush();
			}
		}

		public void Close()
		{
			try 
			{
				T.WriteLineIf(Globals.Trace, "DataAccess.Close():");
				T.Indent();
				//
				// ...
				//
				T.WriteLineIf(Globals.Trace, "Closed.");
			}
			catch(Exception ex) 
			{
				T.WriteLineIf(Globals.Trace, ex.GetType() + ": " + ex.Message);
				T.WriteLineIf(Globals.Trace, ex.StackTrace);
			}
			finally 
			{
				T.Unindent();
				T.Flush();
			}
		}

	}//class

}//namespace
